@@ -85,6 +85,22 @@ elsif($^O eq 'linux' && -f '/etc/gentoo-release')
   }
 }
 
+elsif($^O eq 'linux' && -f '/etc/alpine-release')
+{                  
+  $status{pkg_config_dir}    = [qw(
+    /usr/lib/pkgconfig
+    /usr/share/pkgconfig
+  )];                                                          
+  $status{system_libdir}     = [qw(
+    /lib
+    /usr/lib
+  )];
+  $status{system_includedir} = [qw(
+        /usr/include
+  )];
+
+}
+
 elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version")
 {
 
